@@ -10,17 +10,17 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.9-89.13.AXS2.src.rpm ]
+if [ ! -r kernel-2.6.9-89.16.AXS2.src.rpm ]
 then
-    wget http://ftp.miraclelinux.com/pub/Miracle/ia32/standard/4.0/updates/SRPMS/kernel-2.6.9-89.13.AXS2.src.rpm || die "Can't download source package."
+    wget http://ftp.miraclelinux.com/pub/Miracle/ia32/standard/4.0/updates/SRPMS/kernel-2.6.9-89.16.AXS2.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-2.6.9-89.13.AXS2.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-2.6.9-89.13.AXS2.src.rpm || die "Can't install source package."
+rpm --checksig kernel-2.6.9-89.16.AXS2.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-2.6.9-89.16.AXS2.src.rpm || die "Can't install source package."
 
 cd /usr/src/asianux/SOURCES/ || die "Can't chdir to /usr/src/asianux/SOURCES/ ."
-if [ ! -r ccs-patch-1.7.2-20100923.tar.gz ]
+if [ ! -r ccs-patch-1.7.2-20101122.tar.gz ]
 then
-    wget http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.2-20100923.tar.gz || die "Can't download patch."
+    wget -O ccs-patch-1.7.2-20101122.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.2-20101122.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -32,8 +32,8 @@ patch << "EOF" || die "Can't patch spec file."
  # that the kernel isn't the stock distribution kernel, for example by
  # adding some text to the end of the version number.
  #
--%define release 89.13%{?dist}
-+%define release 89.13%{?dist}_tomoyo_1.7.2p3
+-%define release 89.16%{?dist}
++%define release 89.16%{?dist}_tomoyo_1.7.2p4
  %define sublevel 9
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
@@ -47,7 +47,7 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -175,7 +178,7 @@
+@@ -177,7 +180,7 @@
  %define __find_provides /usr/lib/rpm/asianux/find-kmod-provides.sh
  %define __find_requires %{nil}
  
@@ -56,18 +56,18 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{rpmversion}
-@@ -6238,6 +6241,10 @@
+@@ -6282,6 +6285,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.7.2-20100923.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.7.2-20101122.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.9-asianux-2.diff
 +
  cp %{SOURCE10} Documentation/
  
  mkdir configs
-@@ -6249,6 +6256,9 @@
+@@ -6293,6 +6300,9 @@
  for i in *.config 
  do 
  	mv $i .config 
