@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for Fedora 13's 2.6.34 kernel.
+# This is a kernel build script for Fedora 12's 2.6.32 kernel.
 #
 
 die () {
@@ -10,17 +10,17 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.34.7-56.fc13.src.rpm ]
+if [ ! -r kernel-2.6.32.23-170.fc12.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/updates/13/SRPMS/kernel-2.6.34.7-56.fc13.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/updates/12/SRPMS/kernel-2.6.32.23-170.fc12.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-2.6.34.7-56.fc13.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-2.6.34.7-56.fc13.src.rpm || die "Can't install source package."
+rpm --checksig kernel-2.6.32.23-170.fc12.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-2.6.32.23-170.fc12.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.7.2-20100923.tar.gz ]
+if [ ! -r ccs-patch-1.7.2-20101122.tar.gz ]
 then
-    wget http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.2-20100923.tar.gz || die "Can't download patch."
+    wget -O ccs-patch-1.7.2-20101122.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.2-20101122.tar.gz' || die "Can't download patch."
 fi
 
 cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
@@ -28,16 +28,16 @@ cp -p kernel.spec ccs-kernel.spec || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
 --- ccs-kernel.spec
 +++ ccs-kernel.spec
-@@ -23,7 +23,7 @@
- #
- # (Uncomment the '#' and both spaces below to set the buildid.)
+@@ -22,7 +22,7 @@
+ # appended to the full kernel version.
  #
+ # (Uncomment the '#' and the first two spaces below to set buildid.)
 -# % define buildid .local
-+%define buildid _tomoyo_1.7.2p3
++%define buildid _tomoyo_1.7.2p4
  ###################################################################
  
  # The buildid can also be specified on the rpmbuild command line
-@@ -409,6 +409,11 @@
+@@ -429,6 +429,11 @@
  # to versions below the minimum
  #
  
@@ -49,7 +49,16 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -471,7 +476,7 @@
+@@ -464,7 +469,7 @@
+ # Packages that need to be installed before the kernel is, because the %post
+ # scripts use them.
+ #
+-%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, kernel-firmware >= %{rpmversion}-%{pkg_release}, grubby >= 7.0.4-1
++%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, grubby >= 7.0.4-1
+ %if %{with_dracut}
+ %define initrd_prereq  dracut >= 002 xorg-x11-drv-ati-firmware
+ %else
+@@ -500,7 +505,7 @@
  AutoProv: yes\
  %{nil}
  
@@ -58,7 +67,7 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -910,7 +915,7 @@
+@@ -945,7 +950,7 @@
  Provides: kernel-devel-uname-r = %{KVERREL}%{?1:.%{1}}\
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
@@ -67,18 +76,18 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -1527,6 +1532,10 @@
- 
- # END OF PATCH APPLICATIONS
- 
-+# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.7.2-20100923.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.34-fedora-13.diff
-+
+@@ -1554,6 +1559,10 @@
+ # END OF PATCH APPLICATIONS ====================================================
  %endif
  
++# TOMOYO Linux
++tar -zxf %_sourcedir/ccs-patch-1.7.2-20101122.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.32-fedora-12.diff
++
  # Any further pre-build tree manipulations happen here.
-@@ -1555,6 +1564,9 @@
+ 
+ chmod +x scripts/checkpatch.pl
+@@ -1580,6 +1589,9 @@
  for i in *.config
  do
    mv $i .config
@@ -101,7 +110,7 @@ sleep 30
 patch << "EOF" || die "Can't patch spec file."
 --- /root/rpmbuild/SPECS/ccs-kernel.spec
 +++ /root/rpmbuild/SPECS/ccs-kernel.spec
-@@ -221,7 +221,7 @@
+@@ -224,7 +224,7 @@
  
  # kernel-PAE is only built on i686.
  %ifarch i686
