@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2010  NTT DATA CORPORATION
  *
- * Version: 1.7.2   2010/04/01
+ * Version: 1.7.2+   2010/09/18
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -104,360 +104,6 @@ static const u8 ccs_pn2mac[CCS_MAX_PATH_NUMBER_OPERATION] = {
 	[CCS_TYPE_CHGRP]  = CCS_MAC_FILE_CHGRP,
 };
 
-/*
- * Below part contains copy of some of VFS helper functions.
- *
- * Since TOMOYO Linux requires "struct vfsmount" parameter to calculate
- * an absolute pathname of the requested "struct dentry" parameter
- * but the VFS helper functions don't receive "struct vfsmount" parameter,
- * TOMOYO Linux checks permission outside VFS helper functions.
- * To keep the DAC's permission checks are performed before the
- * TOMOYO Linux's permission checks are performed, I'm manually copying
- * these functions that performs the DAC's permission checks from fs/namei.c .
- */
-
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 5, 0)
-
-/* Permission checks from vfs_create(). */
-static inline int ccs_pre_vfs_create(struct inode *dir, struct dentry *dentry)
-{
-	int error;
-	down(&dir->i_zombie);
-	error = ccsecurity_exports.may_create(dir, dentry);
-	if (!error && (!dir->i_op || !dir->i_op->create))
-		error = -EACCES;
-	up(&dir->i_zombie);
-	return error;
-}
-
-/* Permission checks from vfs_mknod(). */
-static int ccs_pre_vfs_mknod(struct inode *dir, struct dentry *dentry)
-{
-	int error;
-	down(&dir->i_zombie);
-	error = ccsecurity_exports.may_create(dir, dentry);
-	if (!error && (!dir->i_op || !dir->i_op->mknod))
-		error = -EPERM;
-	up(&dir->i_zombie);
-	return error;
-}
-
-/* Permission checks from vfs_mkdir(). */
-static inline int ccs_pre_vfs_mkdir(struct inode *dir, struct dentry *dentry)
-{
-	int error;
-	down(&dir->i_zombie);
-	error = ccsecurity_exports.may_create(dir, dentry);
-	if (!error && (!dir->i_op || !dir->i_op->mkdir))
-		error = -EPERM;
-	up(&dir->i_zombie);
-	return error;
-}
-
-/* Permission checks from vfs_rmdir(). */
-static inline int ccs_pre_vfs_rmdir(struct inode *dir, struct dentry *dentry)
-{
-	int error = ccsecurity_exports.may_delete(dir, dentry, 1);
-	if (!error && (!dir->i_op || !dir->i_op->rmdir))
-		error = -EPERM;
-	return error;
-}
-
-/* Permission checks from vfs_unlink(). */
-static inline int ccs_pre_vfs_unlink(struct inode *dir, struct dentry *dentry)
-{
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 4, 33)
-	int error;
-	down(&dir->i_zombie);
-	error = ccsecurity_exports.may_delete(dir, dentry, 0);
-	if (!error && (!dir->i_op || !dir->i_op->unlink))
-		error = -EPERM;
-	up(&dir->i_zombie);
-	return error;
-#else
-	int error;
-	struct inode *inode;
-	error = ccsecurity_exports.may_delete(dir, dentry, 0);
-	if (error)
-		return error;
-	inode = dentry->d_inode;
-	atomic_inc(&inode->i_count);
-	double_down(&dir->i_zombie, &inode->i_zombie);
-	error = -EPERM;
-	if (dir->i_op && dir->i_op->unlink)
-		error = 0;
-	double_up(&dir->i_zombie, &inode->i_zombie);
-	iput(inode);
-	return error;
-#endif
-}
-
-/* Permission checks from vfs_symlink(). */
-static inline int ccs_pre_vfs_symlink(struct inode *dir, struct dentry *dentry)
-{
-	int error;
-	down(&dir->i_zombie);
-	error = ccsecurity_exports.may_create(dir, dentry);
-	if (error)
-		goto exit_lock;
-	if (!dir->i_op || !dir->i_op->symlink)
-		error = -EPERM;
- exit_lock:
-	up(&dir->i_zombie);
-	return error;
-}
-
-/* Permission checks from vfs_link(). */
-static inline int ccs_pre_vfs_link(struct dentry *old_dentry,
-				   struct inode *dir,
-				   struct dentry *new_dentry)
-{
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 4, 33)
-	struct inode *inode;
-	int error;
-	down(&dir->i_zombie);
-	error = -ENOENT;
-	inode = old_dentry->d_inode;
-	if (!inode)
-		goto exit_lock;
-	error = ccsecurity_exports.may_create(dir, new_dentry);
-	if (error)
-		goto exit_lock;
-	error = -EXDEV;
-	if (dir->i_dev != inode->i_dev)
-		goto exit_lock;
-	error = -EPERM;
-	if (IS_APPEND(inode) || IS_IMMUTABLE(inode))
-		goto exit_lock;
-	if (!dir->i_op || !dir->i_op->link)
-		goto exit_lock;
-	error = 0;
- exit_lock:
-	up(&dir->i_zombie);
-	return error;
-#else
-	struct inode *inode;
-	int error;
-	error = -ENOENT;
-	inode = old_dentry->d_inode;
-	if (!inode)
-		goto exit;
-	error = -EXDEV;
-	if (dir->i_dev != inode->i_dev)
-		goto exit;
-	double_down(&dir->i_zombie, &old_dentry->d_inode->i_zombie);
-	error = ccsecurity_exports.may_create(dir, new_dentry);
-	if (error)
-		goto exit_lock;
-	error = -EPERM;
-	if (IS_APPEND(inode) || IS_IMMUTABLE(inode))
-		goto exit_lock;
-	if (!dir->i_op || !dir->i_op->link)
-		goto exit_lock;
-	error = 0;
- exit_lock:
-	double_up(&dir->i_zombie, &old_dentry->d_inode->i_zombie);
- exit:
-	return error;
-#endif
-}
-
-/* Permission checks from vfs_rename_dir(). */
-static inline int ccs_pre_vfs_rename_dir(struct inode *old_dir,
-					 struct dentry *old_dentry,
-					 struct inode *new_dir,
-					 struct dentry *new_dentry)
-{
-	int error;
-	if (old_dentry->d_inode == new_dentry->d_inode)
-		return 0;
-	error = ccsecurity_exports.may_delete(old_dir, old_dentry, 1);
-	if (error)
-		return error;
-	if (new_dir->i_dev != old_dir->i_dev)
-		return -EXDEV;
-	if (!new_dentry->d_inode)
-		error = ccsecurity_exports.may_create(new_dir, new_dentry);
-	else
-		error = ccsecurity_exports.may_delete(new_dir, new_dentry, 1);
-	if (error)
-		return error;
-	if (!old_dir->i_op || !old_dir->i_op->rename)
-		return -EPERM;
-	if (new_dir != old_dir)
-		error = permission(old_dentry->d_inode, MAY_WRITE);
-	return error;
-}
-
-/* Permission checks from vfs_rename_other(). */
-static inline int ccs_pre_vfs_rename_other(struct inode *old_dir,
-					   struct dentry *old_dentry,
-					   struct inode *new_dir,
-					   struct dentry *new_dentry)
-{
-	int error;
-	if (old_dentry->d_inode == new_dentry->d_inode)
-		return 0;
-	error = ccsecurity_exports.may_delete(old_dir, old_dentry, 0);
-	if (error)
-		return error;
-	if (new_dir->i_dev != old_dir->i_dev)
-		return -EXDEV;
-	if (!new_dentry->d_inode)
-		error = ccsecurity_exports.may_create(new_dir, new_dentry);
-	else
-		error = ccsecurity_exports.may_delete(new_dir, new_dentry, 0);
-	if (error)
-		return error;
-	if (!old_dir->i_op || !old_dir->i_op->rename)
-		return -EPERM;
-	return 0;
-}
-
-/* Permission checks from vfs_rename(). */
-static inline int ccs_pre_vfs_rename(struct inode *old_dir,
-				     struct dentry *old_dentry,
-				     struct inode *new_dir,
-				     struct dentry *new_dentry)
-{
-	int error;
-	lock_kernel(); /* From do_rename(). */
-	if (S_ISDIR(old_dentry->d_inode->i_mode))
-		error = ccs_pre_vfs_rename_dir(old_dir, old_dentry,
-					       new_dir, new_dentry);
-	else
-		error = ccs_pre_vfs_rename_other(old_dir, old_dentry,
-						 new_dir, new_dentry);
-	unlock_kernel(); /* From do_rename(). */
-	return error;
-}
-
-#else
-
-/* Permission checks from vfs_create(). */
-static inline int ccs_pre_vfs_create(struct inode *dir, struct dentry *dentry)
-{
-	int error = ccsecurity_exports.may_create(dir, dentry, 0);
-	if (error)
-		return error;
-	if (!dir->i_op || !dir->i_op->create)
-		return -EACCES; /* shouldn't it be ENOSYS? */
-	return 0;
-}
-
-/* Permission checks from vfs_mknod(). */
-static int ccs_pre_vfs_mknod(struct inode *dir, struct dentry *dentry)
-{
-	int error = ccsecurity_exports.may_create(dir, dentry, 0);
-	if (error)
-		return error;
-	if (!dir->i_op || !dir->i_op->mknod)
-		return -EPERM;
-	return 0;
-}
-
-/* Permission checks from vfs_mkdir(). */
-static inline int ccs_pre_vfs_mkdir(struct inode *dir, struct dentry *dentry)
-{
-	int error = ccsecurity_exports.may_create(dir, dentry, 1);
-	if (error)
-		return error;
-	if (!dir->i_op || !dir->i_op->mkdir)
-		return -EPERM;
-	return 0;
-}
-
-/* Permission checks from vfs_rmdir(). */
-static inline int ccs_pre_vfs_rmdir(struct inode *dir, struct dentry *dentry)
-{
-	int error = ccsecurity_exports.may_delete(dir, dentry, 1);
-	if (error)
-		return error;
-	if (!dir->i_op || !dir->i_op->rmdir)
-		return -EPERM;
-	return 0;
-}
-
-/* Permission checks from vfs_unlink(). */
-static inline int ccs_pre_vfs_unlink(struct inode *dir, struct dentry *dentry)
-{
-	int error = ccsecurity_exports.may_delete(dir, dentry, 0);
-	if (error)
-		return error;
-	if (!dir->i_op || !dir->i_op->unlink)
-		return -EPERM;
-	return 0;
-}
-
-/* Permission checks from vfs_link(). */
-static inline int ccs_pre_vfs_link(struct dentry *old_dentry,
-				   struct inode *dir,
-				   struct dentry *new_dentry)
-{
-	struct inode *inode = old_dentry->d_inode;
-	int error;
-	if (!inode)
-		return -ENOENT;
-	error = ccsecurity_exports.may_create(dir, new_dentry, 0);
-	if (error)
-		return error;
-	if (dir->i_sb != inode->i_sb)
-		return -EXDEV;
-	if (IS_APPEND(inode) || IS_IMMUTABLE(inode))
-		return -EPERM;
-	if (!dir->i_op || !dir->i_op->link)
-		return -EPERM;
-	if (S_ISDIR(old_dentry->d_inode->i_mode))
-		return -EPERM;
-	return 0;
-}
-
-/* Permission checks from vfs_symlink(). */
-static inline int ccs_pre_vfs_symlink(struct inode *dir, struct dentry *dentry)
-{
-	int error = ccsecurity_exports.may_create(dir, dentry, 0);
-	if (error)
-		return error;
-	if (!dir->i_op || !dir->i_op->symlink)
-		return -EPERM;
-	return 0;
-}
-
-/* Permission checks from vfs_rename(). */
-static inline int ccs_pre_vfs_rename(struct inode *old_dir,
-				     struct dentry *old_dentry,
-				     struct inode *new_dir,
-				     struct dentry *new_dentry)
-{
-	int error;
-	const int is_dir = S_ISDIR(old_dentry->d_inode->i_mode);
-	if (old_dentry->d_inode == new_dentry->d_inode)
-		return 0;
-	error = ccsecurity_exports.may_delete(old_dir, old_dentry, is_dir);
-	if (error)
-		return error;
-	if (!new_dentry->d_inode)
-		error = ccsecurity_exports.may_create(new_dir, new_dentry,
-						      is_dir);
-	else
-		error = ccsecurity_exports.may_delete(new_dir, new_dentry,
-						      is_dir);
-	if (error)
-		return error;
-	if (!old_dir->i_op || !old_dir->i_op->rename)
-		return -EPERM;
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 27)
-	if (is_dir && new_dir != old_dir)
-		error = permission(old_dentry->d_inode, MAY_WRITE, NULL);
-#else
-	if (is_dir && new_dir != old_dir)
-		error = inode_permission(old_dentry->d_inode, MAY_WRITE);
-#endif
-	return error;
-}
-
-#endif
-
 /* Main functions. */
 
 void ccs_put_name_union(struct ccs_name_union *ptr)
@@ -838,12 +484,13 @@ const char *ccs_file_pattern(const struct ccs_path_info *filename)
 int ccs_write_pattern_policy(char *data, const bool is_delete)
 {
 	struct ccs_pattern_entry *ptr;
-	struct ccs_pattern_entry e = { .pattern = ccs_get_name(data) };
+	struct ccs_pattern_entry e = { };
 	int error = is_delete ? -ENOENT : -ENOMEM;
+	if (!ccs_is_correct_path(data, 0, 1, 0))
+		return -EINVAL;
+	e.pattern = ccs_get_name(data);
 	if (!e.pattern)
 		return error;
-	if (!e.pattern->is_patterned)
-		goto out;
 	if (mutex_lock_interruptible(&ccs_policy_lock))
 		goto out;
 	list_for_each_entry_rcu(ptr, &ccs_pattern_list, list) {
@@ -1044,7 +691,7 @@ static int ccs_path_acl(struct ccs_request_info *r,
 			const struct ccs_path_info *filename,
 			const u16 perm, const bool may_use_pattern)
 {
-	struct ccs_domain_info *domain = r->domain;
+	const struct ccs_domain_info * const domain = ccs_current_domain();
 	struct ccs_acl_info *ptr;
 	int error = -EPERM;
 	list_for_each_entry_rcu(ptr, &domain->acl_info_list, list) {
@@ -1083,7 +730,7 @@ static int ccs_path_number3_acl(struct ccs_request_info *r,
 				const unsigned int major,
 				const unsigned int minor)
 {
-	struct ccs_domain_info *domain = r->domain;
+	const struct ccs_domain_info * const domain = ccs_current_domain();
 	struct ccs_acl_info *ptr;
 	int error = -EPERM;
 	list_for_each_entry_rcu(ptr, &domain->acl_info_list, list) {
@@ -1125,6 +772,7 @@ static int ccs_file_perm(struct ccs_request_info *r,
 	const char *msg = "<unknown>";
 	int error = 0;
 	u16 perm = 0;
+	const struct ccs_domain_info * const domain = ccs_current_domain();
 	if (!filename)
 		return 0;
 	if (mode == 6) {
@@ -1143,7 +791,7 @@ static int ccs_file_perm(struct ccs_request_info *r,
 		BUG();
 	do {
 		error = ccs_path_acl(r, filename, perm, mode != 1);
-		if (error && mode == 4 && !r->domain->ignore_global_allow_read
+		if (error && mode == 4 && !domain->ignore_global_allow_read
 		    && ccs_is_globally_readable_file(filename))
 			error = 0;
 		ccs_audit_path_log(r, msg, filename->name, !error);
@@ -1386,11 +1034,9 @@ static inline int ccs_update_path_number3_acl(const u8 type,
  *
  * Returns 0 on success, negative value otherwise.
  */
-static inline int ccs_update_path2_acl(const u8 type,
-				       const char *filename1,
+static inline int ccs_update_path2_acl(const u8 type, const char *filename1,
 				       const char *filename2,
-				       struct ccs_domain_info * const
-				       domain,
+				       struct ccs_domain_info * const domain,
 				       struct ccs_condition *condition,
 				       const bool is_delete)
 {
@@ -1455,7 +1101,7 @@ static int ccs_path2_acl(struct ccs_request_info *r, const u8 type,
 			 const struct ccs_path_info *filename1,
 			 const struct ccs_path_info *filename2)
 {
-	const struct ccs_domain_info *domain = r->domain;
+	const struct ccs_domain_info * const domain = ccs_current_domain();
 	struct ccs_acl_info *ptr;
 	const u8 perm = 1 << type;
 	int error = -EPERM;
@@ -1492,7 +1138,8 @@ int ccs_path_permission(struct ccs_request_info *r, u8 operation,
 	const char *msg;
 	int error;
  repeat:
-	r->mode = ccs_get_mode(r->profile, ccs_p2mac[operation]);
+	r->type = ccs_p2mac[operation];
+	r->mode = ccs_get_mode(r->profile, r->type);
 	if (r->mode == CCS_CONFIG_DISABLED)
 		return 0;
 	do {
@@ -1647,7 +1294,7 @@ static int __ccs_open_permission(struct dentry *dentry, struct vfsmount *mnt,
 	if (!mnt || (dentry->d_inode && S_ISDIR(dentry->d_inode->i_mode)))
 		return 0;
 	buf.name = NULL;
-	r.mode = 0;
+	r.mode = CCS_CONFIG_DISABLED;
 	idx = ccs_read_lock();
 	/*
 	 * If the filename is specified by "deny_rewrite" keyword,
@@ -1655,7 +1302,7 @@ static int __ccs_open_permission(struct dentry *dentry, struct vfsmount *mnt,
 	 * opened for append mode or the filename is truncated at open time.
 	 */
 	if ((acc_mode & MAY_WRITE) && !(flag & O_APPEND)
-	    && ccs_init_request_info(&r, NULL, CCS_MAC_FILE_REWRITE)
+	    && ccs_init_request_info(&r, CCS_MAC_FILE_REWRITE)
 	    != CCS_CONFIG_DISABLED) {
 		if (!ccs_get_realpath(&buf, dentry, mnt)) {
 			error = -ENOMEM;
@@ -1668,7 +1315,7 @@ static int __ccs_open_permission(struct dentry *dentry, struct vfsmount *mnt,
 		}
 	}
 	if (!error && acc_mode &&
-	    ccs_init_request_info(&r, NULL, CCS_MAC_FILE_OPEN)
+	    ccs_init_request_info(&r, CCS_MAC_FILE_OPEN)
 	    != CCS_CONFIG_DISABLED) {
 		if (!buf.name && !ccs_get_realpath(&buf, dentry, mnt)) {
 			error = -ENOMEM;
@@ -1679,7 +1326,7 @@ static int __ccs_open_permission(struct dentry *dentry, struct vfsmount *mnt,
 	}
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 33)
 	if (!error && (flag & O_TRUNC) &&
-	    ccs_init_request_info(&r, NULL, CCS_MAC_FILE_TRUNCATE)
+	    ccs_init_request_info(&r, CCS_MAC_FILE_TRUNCATE)
 	    != CCS_CONFIG_DISABLED) {
 		if (!buf.name && !ccs_get_realpath(&buf, dentry, mnt)) {
 			error = -ENOMEM;
@@ -1727,23 +1374,10 @@ static int ccs_path_perm(const u8 operation, struct inode *dir,
 	buf.name = NULL;
 	symlink_target.name = NULL;
 	idx = ccs_read_lock();
-	if (ccs_init_request_info(&r, NULL, ccs_p2mac[operation])
+	if (ccs_init_request_info(&r, ccs_p2mac[operation])
 	    == CCS_CONFIG_DISABLED)
 		goto out;
 	is_enforce = (r.mode == CCS_CONFIG_ENFORCING);
-	switch (operation) {
-	case CCS_TYPE_RMDIR:
-		error = ccs_pre_vfs_rmdir(dir, dentry);
-		break;
-	case CCS_TYPE_UNLINK:
-		error = ccs_pre_vfs_unlink(dir, dentry);
-		break;
-	case CCS_TYPE_SYMLINK:
-		error = ccs_pre_vfs_symlink(dir, dentry);
-		break;
-	}
-	if (error)
-		goto out;
 	error = -ENOMEM;
 	if (!ccs_get_realpath(&buf, dentry, mnt))
 		goto out;
@@ -1751,7 +1385,6 @@ static int ccs_path_perm(const u8 operation, struct inode *dir,
 	switch (operation) {
 	case CCS_TYPE_RMDIR:
 	case CCS_TYPE_CHROOT:
-	case CCS_TYPE_UMOUNT:
 		ccs_add_slash(&buf);
 		break;
 	case CCS_TYPE_SYMLINK:
@@ -1803,13 +1436,10 @@ static int ccs_path_number3_perm(const u8 operation, struct inode *dir,
 		return 0;
 	buf.name = NULL;
 	idx = ccs_read_lock();
-	if (ccs_init_request_info(&r, NULL, ccs_pnnn2mac[operation])
+	if (ccs_init_request_info(&r, ccs_pnnn2mac[operation])
 	    == CCS_CONFIG_DISABLED)
 		goto out;
 	is_enforce = (r.mode == CCS_CONFIG_ENFORCING);
-	error = ccs_pre_vfs_mknod(dir, dentry);
-	if (error)
-		goto out;
 	error = -EPERM;
 	if (!capable(CAP_MKNOD))
 		goto out;
@@ -1851,7 +1481,7 @@ static int __ccs_rewrite_permission(struct file *filp)
 		return 0;
 	buf.name = NULL;
 	idx = ccs_read_lock();
-	if (ccs_init_request_info(&r, NULL, CCS_MAC_FILE_REWRITE)
+	if (ccs_init_request_info(&r, CCS_MAC_FILE_REWRITE)
 	    == CCS_CONFIG_DISABLED)
 		goto out;
 	is_enforce = (r.mode == CCS_CONFIG_ENFORCING);
@@ -1906,20 +1536,10 @@ static int ccs_path2_perm(const u8 operation, struct inode *dir1,
 	buf1.name = NULL;
 	buf2.name = NULL;
 	idx = ccs_read_lock();
-	if (ccs_init_request_info(&r, NULL, ccs_pp2mac[operation])
+	if (ccs_init_request_info(&r, ccs_pp2mac[operation])
 	    == CCS_CONFIG_DISABLED)
 		goto out;
 	is_enforce = (r.mode == CCS_CONFIG_ENFORCING);
-	switch (operation) {
-	case CCS_TYPE_RENAME:
-		error = ccs_pre_vfs_rename(dir1, dentry1, dir2, dentry2);
-		break;
-	case CCS_TYPE_LINK:
-		error = ccs_pre_vfs_link(dentry1, dir2, dentry2);
-		break;
-	}
-	if (error)
-		goto out;
 	error = -ENOMEM;
 	if (!ccs_get_realpath(&buf1, dentry1, mnt1) ||
 	    !ccs_get_realpath(&buf2, dentry2, mnt2))
@@ -1933,6 +1553,7 @@ static int ccs_path2_perm(const u8 operation, struct inode *dir1,
 	case CCS_TYPE_PIVOT_ROOT:
 		ccs_add_slash(&buf1);
 		ccs_add_slash(&buf2);
+		break;
 	}
 	r.obj = &obj;
 	do {
@@ -2038,7 +1659,7 @@ static int ccs_path_number_acl(struct ccs_request_info *r, const u8 type,
 			       const struct ccs_path_info *filename,
 			       const unsigned long number)
 {
-	struct ccs_domain_info *domain = r->domain;
+	const struct ccs_domain_info * const domain = ccs_current_domain();
 	struct ccs_acl_info *ptr;
 	const u8 perm = 1 << type;
 	int error = -EPERM;
@@ -2136,22 +1757,7 @@ static int ccs_path_number_perm(const u8 type, struct inode *dir,
 		return 0;
 	buf.name = NULL;
 	idx = ccs_read_lock();
-	if (ccs_init_request_info(&r, NULL, ccs_pn2mac[type])
-	    == CCS_CONFIG_DISABLED)
-		goto out;
-	switch (type) {
-	case CCS_TYPE_CREATE:
-		error = ccs_pre_vfs_create(dir, dentry);
-		break;
-	case CCS_TYPE_MKDIR:
-		error = ccs_pre_vfs_mkdir(dir, dentry);
-		break;
-	case CCS_TYPE_MKFIFO:
-	case CCS_TYPE_MKSOCK:
-		error = ccs_pre_vfs_mknod(dir, dentry);
-		break;
-	}
-	if (error)
+	if (ccs_init_request_info(&r, ccs_pn2mac[type]) == CCS_CONFIG_DISABLED)
 		goto out;
 	error = -ENOMEM;
 	if (!ccs_get_realpath(&buf, dentry, vfsmnt))
@@ -2443,8 +2049,7 @@ static int __ccs_symlink_permission(struct inode *dir, struct dentry *dentry,
 
 /* Permission checks for notify_change(). */
 static int __ccs_truncate_permission(struct dentry *dentry,
-				     struct vfsmount *mnt, loff_t length,
-				     unsigned int time_attrs)
+				     struct vfsmount *mnt)
 {
 	return ccs_path_perm(CCS_TYPE_TRUNCATE, NULL, dentry, mnt, NULL);
 }
@@ -2515,7 +2120,7 @@ static int __ccs_parse_table(int __user *name, int nlen, void __user *oldval,
 	if (!op) /* Neither read nor write */
 		return 0;
 	idx = ccs_read_lock();
-	if (ccs_init_request_info(&r, NULL, CCS_MAC_FILE_OPEN)
+	if (ccs_init_request_info(&r, CCS_MAC_FILE_OPEN)
 	    == CCS_CONFIG_DISABLED) {
 		error = 0;
 		goto out;
