@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2010  NTT DATA CORPORATION
  *
- * Version: 1.7.2   2010/04/01
+ * Version: 1.7.2+   2010/09/23
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -305,7 +305,7 @@ static void ccs_check_profile(void)
 	if (ccs_profile_version != 20090903)
 		panic("Profile version %u is not supported.\n",
 		      ccs_profile_version);
-	printk(KERN_INFO "CCSecurity: 1.7.2   2010/04/01\n");
+	printk(KERN_INFO "CCSecurity: 1.7.2+   2010/09/23\n");
 	printk(KERN_INFO "Mandatory Access Control activated.\n");
 }
 
@@ -1539,8 +1539,8 @@ static bool ccs_print_signal_acl(struct ccs_io_buffer *head,
  */
 static bool ccs_print_execute_handler_record(struct ccs_io_buffer *head,
 					     const char *keyword,
-					     struct ccs_execute_handler_record *
-					     ptr)
+					     struct ccs_execute_handler_record
+					     *ptr)
 {
 	return ccs_io_printf(head, "%s %s\n", keyword, ptr->handler->name);
 }
@@ -2042,7 +2042,8 @@ static struct ccs_condition *ccs_get_execute_condition(struct ccs_execve_entry
 	int len = 256;
 	char *realpath = NULL;
 	char *argv0 = NULL;
-	const struct ccs_profile *profile = ccs_profile(ee->r.domain->profile);
+	const struct ccs_profile *profile = ccs_profile(ccs_current_domain()->
+							profile);
 	if (profile->learning->learning_exec_realpath) {
 		struct file *file = ee->bprm->file;
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 20)
@@ -2168,8 +2169,7 @@ int ccs_supervisor(struct ccs_request_info *r, const char *fmt, ...)
 	struct ccs_query_entry *ccs_query_entry = NULL;
 	bool quota_exceeded = false;
 	char *header;
-	if (!r->domain)
-		r->domain = ccs_current_domain();
+	struct ccs_domain_info * const domain = ccs_current_domain();
 	switch (r->mode) {
 		char *buffer;
 		struct ccs_condition *cond;
@@ -2195,7 +2195,7 @@ int ccs_supervisor(struct ccs_request_info *r, const char *fmt, ...)
 			cond = ccs_get_condition(str);
 		} else
 			cond = NULL;
-		ccs_write_domain_policy2(buffer, r->domain, cond, false);
+		ccs_write_domain_policy2(buffer, domain, cond, false);
 		ccs_put_condition(cond);
 		kfree(buffer);
 		/* fall through */
@@ -2206,7 +2206,7 @@ int ccs_supervisor(struct ccs_request_info *r, const char *fmt, ...)
 		int i;
 		if (current->ccs_flags & CCS_DONT_SLEEP_ON_ENFORCE_ERROR)
 			return -EPERM;
-		for (i = 0; i < ccs_profile(r->domain->profile)->enforcing->
+		for (i = 0; i < ccs_profile(domain->profile)->enforcing->
 			     enforcing_penalty; i++) {
 			set_current_state(TASK_INTERRUPTIBLE);
 			schedule_timeout(HZ / 10);
@@ -2305,8 +2305,8 @@ static int ccs_poll_query(struct file *file, poll_table *wait)
 	for (i = 0; i < 2; i++) {
 		spin_lock(&ccs_query_list_lock);
 		list_for_each(tmp, &ccs_query_list) {
-			struct ccs_query_entry *ptr
-				= list_entry(tmp, struct ccs_query_entry, list);
+			struct ccs_query_entry *ptr =
+				list_entry(tmp, struct ccs_query_entry, list);
 			if (ptr->answer)
 				continue;
 			found = true;
