@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2010  NTT DATA CORPORATION
  *
- * Version: 1.7.2   2010/04/01
+ * Version: 1.7.2+   2010/06/04
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -42,14 +42,6 @@ int search_binary_handler(struct linux_binprm *bprm, struct pt_regs *regs);
 /* For exporting variables and functions. */
 struct ccsecurity_exports {
 	void (*load_policy) (const char *filename);
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 5, 0)
-	int (*may_create) (struct inode *dir, struct dentry *dentry);
-#else
-	int (*may_create) (struct inode *dir, struct dentry *dentry,
-			   int is_dir);
-#endif
-	int (*may_delete) (struct inode *dir, struct dentry *dentry,
-			   int is_dir);
 	void (*put_filesystem) (struct file_system_type *fs);
 	asmlinkage long (*sys_getppid) (void);
 	asmlinkage long (*sys_getpid) (void);
@@ -108,8 +100,7 @@ struct ccsecurity_operations {
 	int (*symlink_permission) (struct inode *dir, struct dentry *dentry,
 				   struct vfsmount *mnt, const char *from);
 	int (*truncate_permission) (struct dentry *dentry,
-				    struct vfsmount *mnt, loff_t length,
-				    unsigned int time_attrs);
+				    struct vfsmount *mnt);
 	int (*rename_permission) (struct inode *old_dir,
 				  struct dentry *old_dentry,
 				  struct inode *new_dir,
@@ -342,8 +333,7 @@ static inline int ccs_truncate_permission(struct dentry *dentry,
 					  unsigned int time_attrs)
 {
 	return ccsecurity_ops.truncate_permission ?
-		ccsecurity_ops.truncate_permission(dentry, mnt, length,
-						   time_attrs) : 0;
+		ccsecurity_ops.truncate_permission(dentry, mnt) : 0;
 }
 
 static inline int ccs_rename_permission(struct inode *old_dir,
@@ -764,13 +754,6 @@ static inline int ccs_search_binary_handler(struct linux_binprm *bprm,
 
 #endif
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 5, 0)
-int ccs_may_create(struct inode *dir, struct dentry *dentry);
-#else
-int ccs_may_create(struct inode *dir, struct dentry *dentry, int is_dir);
-#endif
-int ccs_may_delete(struct inode *dir, struct dentry *dentry, int is_dir);
-
 /* Index numbers for Capability Controls. */
 enum ccs_capability_acl_index {
 	/* socket(PF_INET or PF_INET6, SOCK_STREAM, *)                 */
